==> haskell-yaml-0.11.11.2-111-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yaml
version:              0.11.11.2
visibility:           public
id:                   yaml-0.11.11.2-HEyJLnR3A9NJG6tnIWlo7S
key:                  yaml-0.11.11.2-HEyJLnR3A9NJG6tnIWlo7S
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov

stability:            stable
homepage:             https://github.com/snoyberg/yaml#readme
synopsis:             Support for parsing and rendering YAML documents.
description:
    README and API documentation are available at <https://www.stackage.org/package/yaml>

category:             Data
abi:                  fe826eba2f8f2e93c3ad9f32f2b4bc43
exposed:              True
exposed-modules:
    Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder Data.Yaml.Config
    Data.Yaml.Include Data.Yaml.Internal Data.Yaml.Parser
    Data.Yaml.Pretty Data.Yaml.TH

hidden-modules:       Paths_yaml
import-dirs:          /usr/lib/ghc-9.4.8/site-local/yaml-0.11.11.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yaml-0.11.11.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yaml-0.11.11.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yaml
hs-libraries:         HSyaml-0.11.11.2-HEyJLnR3A9NJG6tnIWlo7S
depends:
    aeson-2.1.2.1-GOr0sGsn8HVJzt9KhewtB0
    attoparsec-0.14.4-CiUWnNTnUzcEcRmqqSBimu base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-GhV2KMoemFPB5FDryFR5X5
    containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2
    libyaml-0.1.4-KfohsVmTM68Dj9JjrN2uyN mtl-2.2.2
    resourcet-1.2.6-1qaZdHoBp5u2zlBnaE55JI
    scientific-0.3.7.0-6O6FbUTzbTcBhAh2dckDIt template-haskell-2.19.0.0
    text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-Jl6TkouWI2i1D1jczNV0uv
    vector-0.13.2.0-F0gUvA5SUIr11j4RVHYOTP

haddock-interfaces:   /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html:         /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-yaml-0.11.11.2-112-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-yaml.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 yaml
version:              0.11.11.2
visibility:           public
id:                   yaml-0.11.11.2-EfLMyTDGgnw5yoZIhGAGZs
key:                  yaml-0.11.11.2-EfLMyTDGgnw5yoZIhGAGZs
license:              BSD-3-Clause
maintainer:           Michael Snoyman <michael@snoyman.com>
author:
    Michael Snoyman <michael@snoyman.com>, Anton Ageev <antage@gmail.com>,Kirill Simonov

stability:            stable
homepage:             https://github.com/snoyberg/yaml#readme
synopsis:             Support for parsing and rendering YAML documents.
description:
    README and API documentation are available at <https://www.stackage.org/package/yaml>

category:             Data
abi:                  c93eab4fd3c730e924ea5ba8faf219fe
exposed:              True
exposed-modules:
    Data.Yaml Data.Yaml.Aeson Data.Yaml.Builder Data.Yaml.Config
    Data.Yaml.Include Data.Yaml.Internal Data.Yaml.Parser
    Data.Yaml.Pretty Data.Yaml.TH

hidden-modules:       Paths_yaml
import-dirs:          /usr/lib/ghc-9.4.8/site-local/yaml-0.11.11.2
library-dirs:         /usr/lib/ghc-9.4.8/site-local/yaml-0.11.11.2
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/yaml-0.11.11.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-yaml
hs-libraries:         HSyaml-0.11.11.2-EfLMyTDGgnw5yoZIhGAGZs
depends:
    aeson-2.1.2.1-PtSa2Du7ZnC9cVeQoj7Qs
    attoparsec-0.14.4-L0PdW4nkr6mJUEG3ZdEFXH base-4.17.2.1
    bytestring-0.11.5.3 conduit-1.3.6.1-KODsDTHe54N26FyzTue8CU
    containers-0.6.7 directory-1.3.7.1 filepath-1.4.2.2
    libyaml-0.1.4-1zEhbsB40UnGHxjVWfHQgX mtl-2.2.2
    resourcet-1.2.6-GnLJF89DOOQL8wsZDsu1Nb
    scientific-0.3.7.0-I6iMwi20J4G9Jw2tSdEPEK template-haskell-2.19.0.0
    text-2.0.2 transformers-0.5.6.2
    unordered-containers-0.2.20-HNPxulgNQi0FiQ3NUpCOne
    vector-0.13.2.0-KDCTRjRQ0urK2B6TNAGAn8

haddock-interfaces:   /usr/share/doc/haskell-yaml/html/yaml.haddock
haddock-html:         /usr/share/doc/haskell-yaml/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
